# ifndef yyMakeCalls
# define yyMakeCalls

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* MakeCalls_Exit) ARGS ((void));

extern void MakeCalls ARGS ((tTree t));

extern void BeginMakeCalls ARGS ((void));
extern void CloseMakeCalls ARGS ((void));

# endif
